==> domonic-0.4.3.tar.gz: domonic-0.4.3/domonic/constants/keyboard.py <==
"""
    domonic.constants.keyboard
    ====================================

"""


class KeyCode():

    A = '65'  #:
    ALTERNATE = '18'  #:
    B = '66'  #:
    BACKQUOTE = '192'  #:
    BACKSLASH = '220'  #:
    BACKSPACE = '8'  #:
    C = '67'  #:
    CAPS_LOCK = '20'  #:
    COMMA = '188'  #:
    COMMAND = '15'  #:
    CONTROL = '17'  #:
    D = '68'  #:
    DELETE = '46'  #:
    DOWN = '40'  #:
    E = '69'  #:
    END = '35'  #:

    ENTER = '13'  #:
    RETURN = '13'  #:

    EQUAL = '187'  #:
    ESCAPE = '27'  #:
    F = '70'  #:
    F1 = '112'  #:
    F10 = '121'  #:
    F11 = '122'  #:
    F12 = '123'  #:
    F13 = '124'  #:
    F14 = '125'  #:
    F15 = '126'  #:
    F2 = '113'  #:
    F3 = '114'  #:
    F4 = '115'  #:
    F5 = '116'  #:
    F6 = '117'  #:
    F7 = '118'  #:
    F8 = '119'  #:
    F9 = '120'  #:
    G = '71'  #:
    H = '72'  #:
    HOME = '36'  #:
    I = '73'  #:
    INSERT = '45'  #:
    J = '74'  #:
    K = '75'  #:
    L = '76'  #:
    LEFT = '37'  #:
    LEFTBRACKET = '219'  #:
    M = '77'  #:
    MINUS = '189'  #:
    N = '78'  #:
    NUMBER_0 = '48'  #:
    NUMBER_1 = '49'  #:
    NUMBER_2 = '50'  #:
    NUMBER_3 = '51'  #:
    NUMBER_4 = '52'  #:
    NUMBER_5 = '53'  #:
    NUMBER_6 = '54'  #:
    NUMBER_7 = '55'  #:
    NUMBER_8 = '56'  #:
    NUMBER_9 = '57'  #:
    NUMPAD = '21'  #:
    NUMPAD_0 = '96'  #:
    NUMPAD_1 = '97'  #:
    NUMPAD_2 = '98'  #:
    NUMPAD_3 = '99'  #:
    NUMPAD_4 = '100'  #:
    NUMPAD_5 = '101'  #:
    NUMPAD_6 = '102'  #:
    NUMPAD_7 = '103'  #:
    NUMPAD_8 = '104'  #:
    NUMPAD_9 = '105'  #:
    NUMPAD_ADD = '107'  #:
    NUMPAD_DECIMAL = '110'  #:
    NUMPAD_DIVIDE = '111'  #:
    NUMPAD_ENTER = '108'  #:
    NUMPAD_MULTIPLY = '106'  #:
    NUMPAD_SUBTRACT = '109'  #:
    O = '79'  #:
    P = '80'  #:
    PAGE_DOWN = '34'  #:
    PAGE_UP = '33'  #:
    PERIOD = '190'  #:
    Q = '81'  #:
    QUOTE = '222'  #:
    R = '82'  #:
    RIGHT = '39'  #:
    RIGHTBRACKET = '221'  #:
    S = '83'  #:
    SEMICOLON = '186'  #:
    SHIFT = '16'  #: ?? left or right or both?
    SLASH = '191'  #:
    SPACE = '32'  #:
    T = '84'  #:
    TAB = '9'  #:
    U = '85'  #:
    UP = '38'  #:
    V = '86'  #:
    W = '87'  #:
    X = '88'  #:
    Y = '89'  #:
    Z = '9'  #:

    # TODO - modifiers

    def __init__(self):
        """ constructor for the keyboard class """
        pass

==> domonic-0.6.9.tar.gz: domonic-0.6.9/domonic/constants/keyboard.py <==
"""
    domonic.constants.keyboard
    ====================================

"""


class KeyCode():

    A = '65'  #:
    ALTERNATE = '18'  #:
    B = '66'  #:
    BACKQUOTE = '192'  #:
    BACKSLASH = '220'  #:
    BACKSPACE = '8'  #:
    C = '67'  #:
    CAPS_LOCK = '20'  #:
    COMMA = '188'  #:
    COMMAND = '15'  #:
    CONTROL = '17'  #:
    D = '68'  #:
    DELETE = '46'  #:
    DOWN = '40'  #:
    E = '69'  #:
    END = '35'  #:

    ENTER = '13'  #:
    RETURN = '13'  #:

    EQUAL = '187'  #:
    ESCAPE = '27'  #:
    F = '70'  #:
    F1 = '112'  #:
    F10 = '121'  #:
    F11 = '122'  #:
    F12 = '123'  #:
    F13 = '124'  #:
    F14 = '125'  #:
    F15 = '126'  #:
    F2 = '113'  #:
    F3 = '114'  #:
    F4 = '115'  #:
    F5 = '116'  #:
    F6 = '117'  #:
    F7 = '118'  #:
    F8 = '119'  #:
    F9 = '120'  #:
    G = '71'  #:
    H = '72'  #:
    HOME = '36'  #:
    I = '73'  #:
    INSERT = '45'  #:
    J = '74'  #:
    K = '75'  #:
    L = '76'  #:
    LEFT = '37'  #:
    LEFTBRACKET = '219'  #:
    M = '77'  #:
    MINUS = '189'  #:
    N = '78'  #:
    NUMBER_0 = '48'  #:
    NUMBER_1 = '49'  #:
    NUMBER_2 = '50'  #:
    NUMBER_3 = '51'  #:
    NUMBER_4 = '52'  #:
    NUMBER_5 = '53'  #:
    NUMBER_6 = '54'  #:
    NUMBER_7 = '55'  #:
    NUMBER_8 = '56'  #:
    NUMBER_9 = '57'  #:
    NUMPAD = '21'  #:
    NUMPAD_0 = '96'  #:
    NUMPAD_1 = '97'  #:
    NUMPAD_2 = '98'  #:
    NUMPAD_3 = '99'  #:
    NUMPAD_4 = '100'  #:
    NUMPAD_5 = '101'  #:
    NUMPAD_6 = '102'  #:
    NUMPAD_7 = '103'  #:
    NUMPAD_8 = '104'  #:
    NUMPAD_9 = '105'  #:
    NUMPAD_ADD = '107'  #:
    NUMPAD_DECIMAL = '110'  #:
    NUMPAD_DIVIDE = '111'  #:
    NUMPAD_ENTER = '108'  #:
    NUMPAD_MULTIPLY = '106'  #:
    NUMPAD_SUBTRACT = '109'  #:
    O = '79'  #:
    P = '80'  #:
    PAGE_DOWN = '34'  #:
    PAGE_UP = '33'  #:
    PERIOD = '190'  #:
    Q = '81'  #:
    QUOTE = '222'  #:
    R = '82'  #:
    RIGHT = '39'  #:
    RIGHTBRACKET = '221'  #:
    S = '83'  #:
    SEMICOLON = '186'  #:
    SHIFT = '16'  #: ?? left or right or both?
    SLASH = '191'  #:
    SPACE = '32'  #:
    T = '84'  #:
    TAB = '9'  #:
    U = '85'  #:
    UP = '38'  #:
    V = '86'  #:
    W = '87'  #:
    X = '88'  #:
    Y = '89'  #:
    Z = '9'  #:

    # TODO - do the modifiers

    # find attribute by value
    # def get_letter(self, attr):
    #     for key, value in self.__dict__.iteritems():
    #         if value == attr:
    #             return key
    #     return None

    def __init__(self):
        """ constructor for the keyboard class """
        pass
